Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/usr.bin/make make: rename Parse_include_file to IncludeFile



details:   https://anonhg.NetBSD.org/src/rev/49d1ddfd2182
branches:  trunk
changeset: 959145:49d1ddfd2182
user:      rillig <rillig%NetBSD.org@localhost>
date:      Mon Feb 01 22:16:57 2021 +0000

description:
make: rename Parse_include_file to IncludeFile

diffstat:

 usr.bin/make/parse.c                               |  12 ++++++------
 usr.bin/make/unit-tests/directive-include-fatal.mk |   4 ++--
 2 files changed, 8 insertions(+), 8 deletions(-)

diffs (72 lines):

diff -r 043d33cbebb1 -r 49d1ddfd2182 usr.bin/make/unit-tests/directive-include-fatal.mk
--- a/usr.bin/make/unit-tests/directive-include-fatal.mk        Mon Feb 01 22:06:05 2021 +0000
+++ b/usr.bin/make/unit-tests/directive-include-fatal.mk        Mon Feb 01 22:16:57 2021 +0000
@@ -1,4 +1,4 @@
-# $NetBSD: directive-include-fatal.mk,v 1.2 2020/09/13 10:20:11 rillig Exp $
+# $NetBSD: directive-include-fatal.mk,v 1.3 2021/02/01 22:16:57 rillig Exp $
 #
 # Test for the .include directive combined with fatal errors.
 #
@@ -6,7 +6,7 @@
 # suspicious, as if it were possible to suppress fatal errors by including
 # another file.  It was a false alarm though, since Parse_File only handles
 # the top-level makefiles from the command line.  Any included files are
-# handled by Parse_include_file instead, and that function does not reset
+# handled by IncludeFile instead, and that function does not reset
 # the "fatals" counter.
 
 # Using an undefined variable in a condition generates a fatal error.



Home | Main Index | Thread Index | Old Index
diff -r 043d33cbebb1 -r 49d1ddfd2182 usr.bin/make/parse.c
--- a/usr.bin/make/parse.c      Mon Feb 01 22:06:05 2021 +0000
+++ b/usr.bin/make/parse.c      Mon Feb 01 22:16:57 2021 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: parse.c,v 1.536 2021/02/01 22:06:05 rillig Exp $       */
+/*     $NetBSD: parse.c,v 1.537 2021/02/01 22:16:57 rillig Exp $       */
 
 /*
  * Copyright (c) 1988, 1989, 1990, 1993
@@ -84,7 +84,7 @@
  *     Parse_End       Clean up the module
  *
  *     Parse_File      Parse a top-level makefile.  Included files are
  *                     handled by Parse_include_file though.
  *
  *     Parse_IsVar     Return TRUE if the given line is a variable
  *                     assignment. Used by MainParseArgs to determine if
@@ -109,7 +109,7 @@
 #include "pathnames.h"
 
 /*     "@(#)parse.c    8.3 (Berkeley) 3/19/94" */
-MAKE_RCSID("$NetBSD: parse.c,v 1.536 2021/02/01 22:06:05 rillig Exp $");
+MAKE_RCSID("$NetBSD: parse.c,v 1.537 2021/02/01 22:16:57 rillig Exp $");
 
 /* types and constants */
 
@@ -2102,7 +2102,7 @@
  * line options.
  */
 static void
-Parse_include_file(char *file, Boolean isSystem, Boolean depinc, Boolean silent)
+IncludeFile(char *file, Boolean isSystem, Boolean depinc, Boolean silent)
 {
        struct loadedfile *lf;
        char *fullname;         /* full pathname of file */
@@ -2253,7 +2253,7 @@
        (void)Var_Subst(file, VAR_CMDLINE, VARE_WANTRES, &file);
        /* TODO: handle errors */
 
-       Parse_include_file(file, endc == '>', directive[0] == 'd', silent);
+       IncludeFile(file, endc == '>', directive[0] == 'd', silent);
        free(file);
 }
 
@@ -2506,7 +2506,7 @@
                else
                        done = TRUE;
 
-               Parse_include_file(file, FALSE, FALSE, silent);
+               IncludeFile(file, FALSE, FALSE, silent);
        }
 out:
        free(all_files);
@@ -84,7 +84,7 @@
  *
  *     Parse_File      Parse a top-level makefile.  Included files are
- *                     handled by Parse_include_file though.
+ *                     handled by IncludeFile instead.
  *
  *     Parse_IsVar     Return TRUE if the given line is a variable